import { useEditor } from "@/modules/editor";
import { defineComponent } from "vue";
import { object, string } from "vue-types";
import { useCompData } from ".";
import { View } from "../View";

export const Component = defineComponent({
  props: {
    compId: string(),
    value: object<{ url: string; x: number; y: number; s: number }>(),
  },
  emits: ["update:value"],
  setup(props, { emit }) {
    const comp = props.compId ? useCompData(props.compId) : null;
    const { store, controls } = useEditor();
    async function changeVal() {
      const url = await controls.pickCtrl.pickOneImage();
      if (!url) return;

      if (comp) {
        comp.value.url = url;
        comp.value.x = 0;
        comp.value.y = 0;
        comp.value.s = 1;
      } else {
        emit("update:value", { url, x: 0, y: 0, s: 1 });
      }
    }

    return () => {
      const value = comp?.value || props.value;
      const scale = value?.s || 1;
      const ox = value?.x || 0;
      const oy = value?.y || 0;
      const objectFit =
        scale + "" == "1" && ox + "" == "0" && oy + "" == "0"
          ? "cover"
          : "contain";

      return (
        <View
          compId={props.compId}
          onDblclick={store.isEditMode ? changeVal : undefined}
        >
          <img
            class={"w-1/1 h-1/1 object-cover pointer-events-none"}
            style={{
              transform: `scale(${scale}) translate(${ox}%,${oy}%)`,
              objectFit,
            }}
            src={value?.url}
          />
        </View>
      );
    };
  },
});
