import { DesignComp } from "@/modules/editor/defines/DesignTemp/DesignComp";
import { computed, defineComponent } from "vue";
import { string } from "vue-types";
import { useCompData } from ".";
import { CompUI } from "../..";
import { useEditor } from "../../../..";

export const Component = defineComponent({
  props: {
    compId: string().isRequired,
  },
  setup(props, { slots }) {
    const editor = useEditor();
    const { helper } = editor;
    const { children, layout } = useCompData(props.compId);

    const compsGroup = computed(() => {
      const normalArr: DesignComp[] = [];
      const posArr: DesignComp[] = [];
      children.default.forEach((id) => {
        const comp = helper.findComp(id);
        if (!comp) return;
        if (comp.compKey === "Container") {
          posArr.push(comp);
        } else {
          normalArr.push(comp);
        }
      });
      return {
        normalArr,
        posArr,
      };
    });

    return () => (
      <div style={helper.parseLayoutToStyle(layout)}>
        <div class="relative z-10">
          {compsGroup.value.posArr.map((d) => {
            const Comp: any = CompUI[d.compKey]?.Component;
            return Comp ? <Comp key={d.id} compId={d.id} /> : undefined;
          })}
        </div>
        {slots.Container?.(
          compsGroup.value.normalArr.map((comp) => {
            return slots.CompItem?.(comp);
          })
        )}
      </div>
    );
  },
});
