import { DesignComp } from "@/modules/editor/defines/DesignTemp/DesignComp";
import { css } from "@linaria/core";
import { defineUI } from "queenjs";
import { onUnmounted } from "vue";
import { Container, Draggable } from "vue-dndrop";
import { useEditor } from "../../..";
import { HotKeyCtrl } from "../../../controllers/HotKeyCtrl";
import { CompUI } from "../../CompUI";

export default defineUI({
  setup() {
    const editor = useEditor();
    const { actions, helper } = editor;

    const hotKeyCtrl = new HotKeyCtrl(editor);
    hotKeyCtrl.init();
    onUnmounted(() => {
      hotKeyCtrl.destroy();
    });

    return () => {
      const pageRoot = helper.findRootComp();
      return pageRoot ? (
        <CompUI.Page.Component class={contentStyle} compId={pageRoot.id}>
          {{
            Container(children: any) {
              return (
                <Container
                  class="!min-h-750px"
                  group-name="canvas"
                  onDrop={(e: any) => {
                    if (e.payload) {
                      actions.addCompToDesign(e.payload, e.addedIndex);
                    } else {
                      actions.moveComp(e.removedIndex, e.addedIndex);
                    }
                  }}
                  non-drag-area-selector={".drag-disable"}
                >
                  {children}
                </Container>
              );
            },
            CompItem(comp: DesignComp) {
              const Comp = CompUI[comp.compKey].Component;
              return (
                <Draggable>
                  <Comp compId={comp.id} />
                </Draggable>
              );
            },
          }}
        </CompUI.Page.Component>
      ) : null;
    };
  },
});

const contentStyle = css`
  position: relative;
  border: 1px solid transparent;
  user-select: none;
  @apply min-h-750px bg-white;

  .dndrop-container.vertical > .dndrop-draggable-wrapper {
    overflow: unset;
  }
`;
