import { CompUI } from "@/modules/editor/components/CompUI";
import { addCacheToMap } from "@/modules/editor/components/CompUI/defines/createCompId";
import { set } from "lodash";
import { AnyFun } from "queenjs/typing";
import { DesignComp } from "../DesignComp";

export function dataTransform(data: any) {
  data.compMap || (data.compMap = {});

  deepEachComp(data.content, (...args: any[]) => {
    const comp = args.pop();
    set(data.content, args.join("."), comp.id);
    data.compMap[comp.id] = comp;
    if (!comp.children) {
      comp.children = (CompUI as any)[comp.compKey].createComp({
        compKey: comp.compKey,
      }).children;
      addCacheToMap(data.compMap);
    }
  });

  if (!data.compMap.root) {
    data.compMap.root = CompUI.Page.createComp({
      id: "root",
      compKey: "Page",
      layout: data.pageStyle,
      children: {
        default: data.content,
      },
    });
  }
  return data;
}

function deepEachComp(obj: any, itemFn: AnyFun) {
  if (obj instanceof Array) {
    obj.forEach((item, i) => deepEachComp(item, itemFn.bind(null, i)));
  } else if (obj instanceof Object) {
    if (isComp(obj)) {
      deepEachComp(obj.children, itemFn.bind(null, "children"));
      itemFn(obj);
    } else {
      Object.entries(obj).map(([key, item]) => {
        deepEachComp(item, itemFn.bind(null, key));
      });
    }
  }
}

function isComp(obj: any): obj is DesignComp {
  if (obj.compKey) {
    return true;
  } else {
    return false;
  }
}
