import { Dict_Apis } from "@/dict";
import { ModuleRoot } from "queenjs";
import { editActions } from "./actions/edit";
import { ImgCompActions } from "./actions/image";
import { initActions } from "./actions/init";
import { InputEventActions } from "./actions/input";
import components from "./components";
import { HistoryCtrl } from "./controllers/HistoryCtrl";
import { ImagePickController } from "./controllers/ImagePickerController";
import { helpers } from "./helpers";
import { https } from "./https";
import { store } from "./stores";
import { useRoute } from "vue-router";

export class EditorModule extends ModuleRoot {
  config = this.setConfig({
    httpConfig: {
      baseURL: Dict_Apis.promotion,
    },
  });
  components = this.useComponents(components);

  actions = this.createActions([
    initActions,
    editActions,
    ImgCompActions,
    InputEventActions,
  ]);
  https = this.createHttps(https);
  store = this.createStore(store);
  helper = this.createHelper(helpers);

  controls = {
    historyCtrl: new HistoryCtrl(this),
    pickCtrl: new ImagePickController(),
  };

  onReady() {
    this.actions.init();
  }

  jumpIndexHtml(route = "#/") {
    const _params = new URLSearchParams(decodeURIComponent(location.search));
    const host = _params.get("host")
    let link = `${location.origin}/index.html?host=${host}${route}`;
    if (location.host == "www.infish.cn") {
      link = `${location.origin}/projects/queenshow/index.html?host=${host}${route}`;
    }
    location.href = link;
  }
}

export const { useEditor, initEditor } = EditorModule.hook("Editor");
